@@ -32,7 +32,7 @@
   # put sleep in as per new user agreement on FBref
   Sys.sleep(time_pause)
 
-  fixtures_page <- xml2::read_html(fixture_url)
+  fixtures_page <- .load_page(fixture_url)
 
   season_name <- fixtures_page %>% rvest::html_nodes("h2 span") %>% rvest::html_text() %>% .[1]
 
@@ -126,9 +126,11 @@
 
 
 
-#' Get match results
+
+#' Get FBref match results
 #'
 #' Returns the game results for a given league season(s)
+#' Replaces the deprecated function get_match_results
 #'
 #' @param country the three character country code
 #' @param gender gender of competition, either "M" or "F"
@@ -147,15 +149,104 @@
 #' @examples
 #' \dontrun{
 #' try({
-#' df <- get_match_results(country = c("ITA"), gender = "M", season_end_year = 2021)
+#' df <- fb_match_results(country = c("ITA"), gender = "M", season_end_year = 2021)
 #' # for results from English Championship:
-#' df <- get_match_results(country = "ENG", gender = "M", season_end_year = 2021, tier = "2nd")
+#' df <- fb_match_results(country = "ENG", gender = "M", season_end_year = 2021, tier = "2nd")
 #' # for international friendlies:
 #'
 #' })
 #' }
 
+fb_match_results <- function(country, gender, season_end_year, tier = "1st", non_dom_league_url = NA) {
+  main_url <- "https://fbref.com"
+  # .pkg_message("Scraping match results")
+
+  country_abbr <- country
+  gender_M_F <- gender
+  season_end_year_num <- season_end_year
+  comp_tier <- tier
+  cups_url <- non_dom_league_url
+
+  seasons <- read.csv("https://raw.githubusercontent.com/JaseZiv/worldfootballR_data/master/raw-data/all_leages_and_cups/all_competitions.csv", stringsAsFactors = F)
+
+  if(is.na(cups_url)) {
+    fixtures_urls <- seasons %>%
+      dplyr::filter(stringr::str_detect(.data$competition_type, "Leagues")) %>%
+      dplyr::filter(country %in% country_abbr,
+                    gender %in% gender_M_F,
+                    season_end_year %in% season_end_year_num,
+                    tier %in% comp_tier,
+                    !is.na(.data$fixtures_url)) %>%
+      dplyr::arrange(season_end_year) %>%
+      dplyr::pull(.data$fixtures_url) %>% unique()
+  } else {
+    fixtures_urls <- seasons %>%
+      dplyr::filter(.data$comp_url %in% cups_url,
+                    gender %in% gender_M_F,
+                    season_end_year %in% season_end_year_num,
+                    !is.na(.data$fixtures_url)) %>%
+      dplyr::arrange(season_end_year) %>%
+      dplyr::pull(.data$fixtures_url) %>% unique()
+  }
+
+  stopifnot("Data not available for the season(s) selected" = length(fixtures_urls) > 0)
+
+  # create the progress bar with a progress function.
+  # pb <- progress::progress_bar$new(total = length(fixtures_urls))
+
+  all_results <- fixtures_urls %>%
+    purrr::map_df(.get_each_season_results)
+
+  all_results <- seasons %>%
+    dplyr::select(Competition_Name=.data$competition_name, Gender=.data$gender, Country=.data$country, Season_End_Year=.data$season_end_year, .data$seasons_urls, .data$fixtures_url) %>%
+    dplyr::right_join(all_results, by = c("fixtures_url" = "fixture_url")) %>%
+    dplyr::select(-.data$seasons_urls, -.data$fixtures_url) %>%
+    dplyr::mutate(Date = lubridate::ymd(.data$Date)) %>%
+    dplyr::arrange(.data$Country, .data$Competition_Name, .data$Gender, .data$Season_End_Year, .data$Wk, .data$Date, .data$Time) %>% dplyr::distinct(.keep_all = T)
+
+
+  # .pkg_message("Match results finished scraping")
+
+  return(all_results)
+}
+
+
+
+
+
+#' Get match results
+#'
+#' Returns the game results for a given league season(s)
+#'
+#' @param country the three character country code
+#' @param gender gender of competition, either "M" or "F"
+#' @param season_end_year the year(s) the season concludes
+#' @param tier the tier of the league, ie '1st' for the EPL or '2nd' for the Championship and so on
+#' @param non_dom_league_url the URL for Cups and Competitions found at https://fbref.com/en/comps/
+#'
+#' @return returns a dataframe with the results of the competition, season and gender
+#'
+#' @importFrom magrittr %>%
+#' @importFrom rlang .data
+#' @importFrom utils read.csv
+#'
+#' @export
+#'
+#' @examples
+#' \dontrun{
+#' try({
+#' df <- get_match_results(country = c("ITA"), gender = "M", season_end_year = 2021)
+#' # for results from English Championship:
+#' df <- get_match_results(country = "ENG", gender = "M", season_end_year = 2021, tier = "2nd")
+#' # for international friendlies:
+#'
+#' })
+#' }
+
 get_match_results <- function(country, gender, season_end_year, tier = "1st", non_dom_league_url = NA) {
+
+  .Deprecated("fb_match_results")
+
   main_url <- "https://fbref.com"
   # .pkg_message("Scraping match results")
 
